@@ -25,6 +25,8 @@
 #include <langinfo.h>
 #include <locale.h>
 #include <iconv.h>
+#include <errno.h>
+
 
 #include "cobex_core.h"
 #include "cobex_tools.h"
@@ -42,15 +44,15 @@ void help () {
 // Deal with XML parsing
 static void startElement(void *data, const char *el, const char **attr) {
 
-	int nameidx=0;
-	int sizeidx=0;
+	int nameidx=-1;
+	int sizeidx=-1;
 	int i;
 	
 	
 	
-	u_int inBytes;
+	int inBytes;
 	char inOrigMsg[MAXCHARS];
-	u_int outBytes = MAXCHARS;
+	int outBytes = MAXCHARS;
 	char outOrigMsg[MAXCHARS];
 	
 	char *inMsgP = inOrigMsg;
@@ -61,26 +63,48 @@ static void startElement(void *data, const char *el, const char **attr) {
 	
 	setlocale(LC_CTYPE, "");
 	
+	for (i=0; i<MAXCHARS; i++) {
+		outOrigMsg[i]=0;
+	}
+	
 	iconvHandle = iconv_open(nl_langinfo(CODESET), "UTF-8" );
+	
+	// Find the name and size attributes
+	for (i = 0; attr[i]; i += 2) {
+		if (strncmp(attr[i], "name", imin(strlen(attr[i]), 4)) ==0) {nameidx=i+1;}
+		if (strncmp(attr[i], "size", imin(strlen(attr[i]), 4)) ==0) {sizeidx=i+1;}
+	}
+	
+	// If we have a name, convert it to the terminals LOCALE. We're guessing that it will always be
+	// in UTF-8, but one should of course check that.
+	if ( nameidx != -1 ) {
+		inBytes=strlen(attr[nameidx])+1;
+		strncpy(inOrigMsg, attr[nameidx], MAXCHARS);
+		while ( inBytes > 0 ) {
+			sizeHandle = iconv(iconvHandle, &inMsgP, &inBytes, &outMsgP, &outBytes);
+			
+			if ((sizeHandle == -1) && (errno == EILSEQ)) {
+				*outMsgP++ = '?';
+				outBytes--;
+				if ( (*inMsgP & 224) == 192 ) {
+					inBytes -= 2;
+					inMsgP += 2;
+				} else if ( (*inMsgP & 240) == 224 ) {
+					inBytes -= 3;
+					inMsgP += 3;
+				} else if ( (*inMsgP & 248) == 240 ) {
+					inBytes -= 4;
+					inMsgP += 4;
+				}	
+			}
+		}
+	}
 		
 	if (strncmp(el, "parent-folder", imin(strlen(el), 13)) == 0 ) {
 		printf ("..	directory\n");
 	} else if ( (strlen(el) == 6) && (strncmp(el, "folder", 6 ) == 0) ) {
-		for (i = 0; attr[i]; i += 2) {
-			if (strncmp(attr[i], "name", imin(strlen(attr[i]), 4)) ==0) {nameidx=i+1;}
-		}
-		inBytes=strlen(attr[nameidx])+1;
-		strncpy(inOrigMsg, attr[nameidx], MAXCHARS);
-		sizeHandle = iconv(iconvHandle, &inMsgP, &inBytes , &outMsgP, &outBytes);
 		printf ("%s\tdirectory\n",outOrigMsg);
 	} else if (strncmp(el, "file", imin(strlen(el), 4)) == 0 ) {
-		for (i = 0; attr[i]; i += 2) {
-			if (strncmp(attr[i], "name", imin(strlen(attr[i]), 4)) ==0) {nameidx=i+1;}
-			if (strncmp(attr[i], "size", imin(strlen(attr[i]), 4)) ==0) {sizeidx=i+1;}
-		}
-		inBytes=strlen(attr[nameidx])+1;
-		strncpy(inOrigMsg, attr[nameidx], MAXCHARS);
-		sizeHandle = iconv(iconvHandle, &inMsgP, &inBytes, &outMsgP, &outBytes);
 		printf ("%s\t%s\n",outOrigMsg,attr[sizeidx]);
 	}
 	iconv_close(iconvHandle);
