@@ -8,6 +8,7 @@
 * v0.5 - fsn - 04-02-22 - First version
 * v0.6 - fsn - 05-07-19 - Using general signal handling and general path handling
 * v0.7 - fsn - 06-07-29 - Code cleanup
+* v0.8 - fsn - 06-10-12 - i18n support
 *
 * Source:
 *
@@ -75,13 +76,13 @@ int sendFile (char *fileName, char *nameOnDevice, obex_packet *inPacket ) {
 	
 	ctools_buildPath (nameOnDevice, path, name);
 	rc=ctools_recursePath( inPacket, path, UsedPort, OBEX_SETPATH_DONTCREATE );
+	if (rc) {return COBEX_ERR;}
 
 	// Send put start
 
 	obex_opcode_put ( inPacket );
 	obex_hi_length ( inPacket, buf.st_size );
-	obex_hi_name ( inPacket, name, strlen(name)+1 );
-	//obex_hi_name ( inPacket, nameOnDevice, strlen(nameOnDevice)+1 );
+	obex_hi_name3 ( inPacket, name, strlen(name)+1 );
 	cobex_packlgt ( inPacket );
 
 	free(name);
